[![Build Status](https://travis-ci.com/edmundsj/RCWA.svg?branch=master)](https://travis-ci.com/edmundsj/RCWA) [![Coverage Status](https://coveralls.io/repos/github/edmundsj/RCWA/badge.svg?branch=master)](https://coveralls.io/github/edmundsj/RCWA?branch=master) [![Documentation Status](https://readthedocs.org/projects/rcwa/badge/?version=latest)](https://rcwa.readthedocs.io/en/latest/?badge=latest)

Author: Jordan Edmunds

Affiliation: UC Irvine, UC Berkeley

Date Started: 2020/01/05

License: MIT (see LICENSE.txt)

GETTING STARTED
------------------

FEATURES
----------

DOCUMENTATION
----------------
